<?php

namespace Drupal\denormalizer\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Entity\EntityInterface;

interface DenormalizerTableInterface extends ConfigEntityInterface {

  /**
   * Gets the denormalizer table source ID.
   *
   * @return string
   *   The denormalizer table source ID.
   */
  public function getSourceId();

  /**
   * Sets the denormalizer table source ID.
   *
   * @param string $source_id
   *   The denormalizer table source ID.
   *
   * @return $this
   */
  public function setSourceId($source_id);

  /**
   * Gets the denormalizer table source configuration.
   *
   * @return array
   *   The denormalizer table source configuration.
   */
  public function getSourceConfiguration();

  /**
   * Sets the denormalizer table source configuration.
   *
   * @param array $configuration
   *   The denormalizer table source configuration.
   *
   * @return $this
   */
  public function setSourceConfiguration(array $configuration);

  public function getDbTableName();

  public function getBaseTable();

  public function createDatabaseTable(bool $init = FALSE);

  public function insertDataFromEntityIntoDbTable(EntityInterface $entity);

  public function updateDataFromEntityIntoDbTable(EntityInterface $entity);

  public function deleteDataFromEntityIntoDbTable(EntityInterface $entity);

  public function getDbTableFieldsSchema();

  public function isWebformSubmission();

  public function getEntitySelectedFields(bool $base_field_only = FALSE);

  public function getWebformSubmissionSelectedElements();

  public function countRows();

}
